separateProvision: Claims reserving using separation methods of Taylor.

Description Usage Arguments Value Examples

Description

Claims reserving using separation methods of Taylor.

Usage

1
2
3
separateProvision(lossData, freqData,
modelSep = "arithmetic", lambdaK = 0,
B = 1000, seed = NULL)

Arguments

lossData

Matrix of incremental losses cij, for i = 1,...,k origin years (rows) and for j = 1,...,k development years (columns); filled with NAs for i + j > k.

freqData

Vector with the claims number by origin year i for i = 1,...k.

modelSep

Model to be used, can be arithmetic or geometric. Defaults to "arithmetic".

lambdaK

Percentage of the trend in the inflation index. Defaults to 0.

B

Number of iterations to perform in the bootstrapping procedure. Defaults to 1000.

seed

Seed to make bootstrap reproducible.

Value

A list of 5 elements with:

Examples

1
2
3
data("TaylorData")
separateProvision(lossData = TaylorData$lossData,
                  freqData = TaylorData$freqData)

acanadis/provision documentation built on May 5, 2019, 3:54 p.m.