Description Usage Arguments Value Examples
Claims reserving using separation methods of Taylor.
1 2 3 | separateProvision(lossData, freqData,
modelSep = "arithmetic", lambdaK = 0,
B = 1000, seed = NULL)
|
lossData |
Matrix of incremental losses cij,
for i = 1,...,k origin years (rows) and for j = 1,...,k
development years (columns); filled with |
freqData |
Vector with the claims number by origin year i for i = 1,...k. |
modelSep |
Model to be used, can be |
lambdaK |
Percentage of the trend in the inflation index. Defaults to 0. |
B |
Number of iterations to perform in the bootstrapping procedure. Defaults to 1000. |
seed |
Seed to make bootstrap reproducible. |
A list of 5 elements with:
triangle Input data (lossData).
glm.triangle Fitted values by glm modeling.
model glm model.
glm.triangle.bootstrap Three-dimensional array of lower triangles from bootstrap procedure.
summary Summary table.
params List of output parameters.
1 2 3 | data("TaylorData")
separateProvision(lossData = TaylorData$lossData,
freqData = TaylorData$freqData)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.